==> scaleway_api_rs-0.1.1.crate: scaleway_api_rs-0.1.1/src/apis/mod.rs <==
use std::error;
use std::fmt;

#[derive(Debug, Clone)]
pub struct ResponseContent<T> {
    pub status: reqwest::StatusCode,
    pub content: String,
    pub entity: Option<T>,
}

#[derive(Debug)]
pub enum Error<T> {
    Reqwest(reqwest::Error),
    Serde(serde_json::Error),
    Io(std::io::Error),
    ResponseError(ResponseContent<T>),
}

impl<T> fmt::Display for Error<T> {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let (module, e) = match self {
            Error::Reqwest(e) => ("reqwest", e.to_string()),
            Error::Serde(e) => ("serde", e.to_string()),
            Error::Io(e) => ("IO", e.to_string()),
            Error::ResponseError(e) => ("response", format!("status code {}", e.status)),
        };
        write!(f, "error in {}: {}", module, e)
    }
}

impl<T: fmt::Debug> error::Error for Error<T> {
    fn source(&self) -> Option<&(dyn error::Error + 'static)> {
        Some(match self {
            Error::Reqwest(e) => e,
            Error::Serde(e) => e,
            Error::Io(e) => e,
            Error::ResponseError(_) => return None,
        })
    }
}

impl<T> From<reqwest::Error> for Error<T> {
    fn from(e: reqwest::Error) -> Self {
        Error::Reqwest(e)
    }
}

impl<T> From<serde_json::Error> for Error<T> {
    fn from(e: serde_json::Error) -> Self {
        Error::Serde(e)
    }
}

impl<T> From<std::io::Error> for Error<T> {
    fn from(e: std::io::Error) -> Self {
        Error::Io(e)
    }
}

pub fn urlencode<T: AsRef<str>>(s: T) -> String {
    ::url::form_urlencoded::byte_serialize(s.as_ref().as_bytes()).collect()
}

pub mod bootscripts_api;
pub mod clusters_api;
pub mod default_api;
pub mod dns_zones_api;
pub mod flexible_ip_api;
pub mod images_api;
pub mod imports_exports_api;
pub mod ips_api;
pub mod namespaces_api;
pub mod nodes_api;
pub mod os_api;
pub mod placement_groups_api;
pub mod pools_api;
pub mod private_networks_api;
pub mod private_nics_api;
pub mod records_api;
pub mod security_groups_api;
pub mod server_types_api;
pub mod servers_api;
pub mod snapshots_api;
pub mod tags_api;
pub mod user_data_api;
pub mod versions_api;
pub mod volume_types_api;
pub mod volumes_api;

pub mod configuration;

==> scaleway_api_rs-0.1.2.crate: scaleway_api_rs-0.1.2/src/apis/mod.rs <==
use std::error;
use std::fmt;

#[derive(Debug, Clone)]
pub struct ResponseContent<T> {
    pub status: reqwest::StatusCode,
    pub content: String,
    pub entity: Option<T>,
}

#[derive(Debug)]
pub enum Error<T> {
    Reqwest(reqwest::Error),
    Serde(serde_json::Error),
    Io(std::io::Error),
    ResponseError(ResponseContent<T>),
}

impl<T> fmt::Display for Error<T> {
    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
        let (module, e) = match self {
            Error::Reqwest(e) => ("reqwest", e.to_string()),
            Error::Serde(e) => ("serde", e.to_string()),
            Error::Io(e) => ("IO", e.to_string()),
            Error::ResponseError(e) => ("response", format!("status code {}", e.status)),
        };
        write!(f, "error in {}: {}", module, e)
    }
}

impl<T: fmt::Debug> error::Error for Error<T> {
    fn source(&self) -> Option<&(dyn error::Error + 'static)> {
        Some(match self {
            Error::Reqwest(e) => e,
            Error::Serde(e) => e,
            Error::Io(e) => e,
            Error::ResponseError(_) => return None,
        })
    }
}

impl<T> From<reqwest::Error> for Error<T> {
    fn from(e: reqwest::Error) -> Self {
        Error::Reqwest(e)
    }
}

impl<T> From<serde_json::Error> for Error<T> {
    fn from(e: serde_json::Error) -> Self {
        Error::Serde(e)
    }
}

impl<T> From<std::io::Error> for Error<T> {
    fn from(e: std::io::Error) -> Self {
        Error::Io(e)
    }
}

pub fn urlencode<T: AsRef<str>>(s: T) -> String {
    ::url::form_urlencoded::byte_serialize(s.as_ref().as_bytes()).collect()
}

pub mod acl_api;
pub mod backups_api;
pub mod bmc_access_api;
pub mod clusters_api;
pub mod database_instances_api;
pub mod databases_api;
pub mod default_api;
pub mod dns_zones_api;
pub mod engines_api;
pub mod flexible_ip_api;
pub mod images_api;
pub mod imports_exports_api;
pub mod instance_settings_api;
pub mod namespaces_api;
pub mod node_types_api;
pub mod nodes_api;
pub mod offers_api;
pub mod os_api;
pub mod pools_api;
pub mod private_networks_api;
pub mod privileges_api;
pub mod records_api;
pub mod servers_actions_api;
pub mod servers_api;
pub mod snapshots_api;
pub mod tags_api;
pub mod users_api;
pub mod versions_api;

pub mod configuration;
